Coverage for tests/utils_test_data.py: 100%

1"""

2 Test data for scores.utils

3"""

4 import numpy as np

5 import xarray as xr

6

7"""

8 Test data for scores.utils.check_dims

9"""

10 DA_R = xr.DataArray(np.array(1).reshape((1,)), dims=["red"])

11 DA_G = xr.DataArray(np.array(1).reshape((1,)), dims=["green"])

12 DA_B = xr.DataArray(np.array(1).reshape((1,)), dims=["blue"])

13

14 DA_RG = xr.DataArray(np.array(1).reshape((1, 1)), dims=["red", "green"])

15 DA_GB = xr.DataArray(np.array(1).reshape((1, 1)), dims=["green", "blue"])

16

17 DA_RGB = xr.DataArray(np.array(1).reshape((1, 1, 1)), dims=["red", "green", "blue"])

18

19 DS_R = xr.Dataset({"DA_R": DA_R})

20 DS_R_2 = xr.Dataset({"DA_R": DA_R, "DA_R_2": DA_R})

21 DS_G = xr.Dataset({"DA_G": DA_G})

22

23 DS_RG = xr.Dataset({"DA_RG": DA_RG})

24 DS_GB = xr.Dataset({"DA_GB": DA_GB})

25

26 DS_RG_RG = xr.Dataset({"DA_RG": DA_RG, "DA_RG_2": DA_RG})

27 DS_RG_R = xr.Dataset({"DA_RG": DA_RG, "DA_R": DA_R})

28

29 DS_RGB_GB = xr.Dataset({"DA_RGB": DA_RGB, "DA_GB": DA_GB})

30

31 DS_RGB = xr.Dataset({"DA_RGB": DA_RGB})